@@ -92,9 +92,10 @@ def applyNAInsertion(dtable):
         if not dtable.present(vid):
             continue
 
-        navals = {v : np.nan for v in vtable['NAValues'][vid]}
-
         for col in dtable.columns(vid):
+            series              = dtable[:, col.name]
+            values              = vtable['NAValues'][vid].astype(series.dtype)
+            navals              = {v : np.nan for v in values}
             dtable[:, col.name] = dtable[:, col.name].replace(navals)
 
 
@@ -281,10 +282,10 @@ def applyNewLevels(dtable):
         if not dtable.present(vid):
             continue
 
-        valmap = dict(zip(rawlevels[vid], newlevels[vid]))
-
         for col in dtable.columns(vid):
             old                 = dtable[:, col.name]
+            valmap              = dict(zip(rawlevels[vid].astype(old.dtype),
+                                           newlevels[vid]))
             new                 = old.replace(valmap)
             corr                = old.corr(new)
             dtable[:, col.name] = new
