@@ -41,25 +41,26 @@ AVAILABLE_HDF5_STYLES      = exporting_hdf5.HDF5_STYLES
 CLI_ARGUMENTS              = collections.OrderedDict((
 
     ('Input/output files', [
-        ((       'outfile',),        {}),
-        ((       'infile',),         {'nargs'   : '+'}),
-        (('e',   'encoding'),        {'action'  : 'append'}),
-        (('l',   'loader'),          {'nargs'   : 2,
-                                      'metavar' : ('FILE', 'LOADER'),
-                                      'action'  : 'append'}),
-        (('i',   'index'),           {'nargs'   : 2,
-                                      'metavar' : ('FILE', 'INDEX'),
-                                      'action'  : 'append'}),
-        (('ma',  'merge_axis'),      {'choices' : AVAILABLE_MERGE_AXES,
-                                      'default' : DEFAULT_MERGE_AXIS}),
-        (('ms',  'merge_strategy'),  {'choices' : AVAILABLE_MERGE_STRATEGIES,
-                                      'default' : DEFAULT_MERGE_STRATEGY}),
-        (('cfg', 'config_file'),     {'action'  : 'append'}),
-        (('vf',  'variable_file'),   {'action'  : 'append'}),
-        (('df',  'datacoding_file'), {'action'  : 'append'}),
-        (('tf',  'type_file'),       {}),
-        (('pf',  'processing_file'), {}),
-        (('cf',  'category_file'),   {})]),
+        ((       'outfile',),          {}),
+        ((       'infile',),           {'nargs'   : '+'}),
+        (('e',   'encoding'),          {'action'  : 'append'}),
+        (('l',   'loader'),            {'nargs'   : 2,
+                                        'metavar' : ('FILE', 'LOADER'),
+                                        'action'  : 'append'}),
+        (('i',   'index'),             {'nargs'   : 2,
+                                        'metavar' : ('FILE', 'INDEX'),
+                                        'action'  : 'append'}),
+        (('ma',  'merge_axis'),        {'choices' : AVAILABLE_MERGE_AXES,
+                                        'default' : DEFAULT_MERGE_AXIS}),
+        (('ms',  'merge_strategy'),    {'choices' : AVAILABLE_MERGE_STRATEGIES,
+                                        'default' : DEFAULT_MERGE_STRATEGY}),
+        (('rd',  'rename_duplicates'), {'action' : 'store_true'}),
+        (('cfg', 'config_file'),       {'action'  : 'append'}),
+        (('vf',  'variable_file'),     {'action'  : 'append'}),
+        (('df',  'datacoding_file'),   {'action'  : 'append'}),
+        (('tf',  'type_file'),         {}),
+        (('pf',  'processing_file'),   {}),
+        (('cf',  'category_file'),     {})]),
 
     ('Import options', [
         (('s',  'subject'),        {'action' : 'append'}),
@@ -119,6 +120,7 @@ CLI_ARGUMENTS              = collections.OrderedDict((
 
     ('TSV/CSV export options', [
         (('ts',  'tsv_sep'),            {}),
+        (('en',  'escape_newlines'),    {'action'  : 'store_true'}),
         (('tm',  'tsv_missing_values'), {'default' : ''})]),
 
     ('HDF5 export options', [
@@ -222,6 +224,9 @@ CLI_ARGUMENT_HELP = {
     'Options are "naive", "intersection"/"inner", or "union"/'
     '"outer".'.format(DEFAULT_MERGE_STRATEGY),
 
+    'rename_duplicates' :
+    'Rename any duplicate columns so that all columns have a unique name.',
+
     'config_file' :
     'File containing default command line arguments. Can be used multiple '
     'times.',
@@ -348,6 +353,10 @@ CLI_ARGUMENT_HELP = {
     'Do not save non-numeric columns to the main output file.',
 
     # TSV/CSV export options
+    'escape_newlines' :
+    'Escape any newline characters in all non-numeric columns, replacing them '
+    'with a literal "\n" (with the same logic applied to any other escape '
+    'characters).',
     'tsv_sep' :
     'Column separator string to use in output file (default: "," for csv, '
     '"\\t" for tsv).',
@@ -604,9 +613,12 @@ def parseArgs(argv=None, namespace=None):
     """Parses ``funpack`` command line arguments.
 
     :arg argv:      List of arguments to parse.
+
     :arg namespace: Existing ``argparse.Namespace`` - if not provided, an
                     empty one will be created.
+
     :returns:       A tuple containing:
+
                      - an ``argparse.Namespace`` object containing the parsed
                        command-line arguments.
                      - A list of the original arguments that were parsed.
@@ -657,14 +669,18 @@ def _prepareInputAndOutputFiles(args):
 
     # the importing.loadData function accepts
     # either a single encoding, or one encoding
-    # for each data file.
+    # for each data file. If the former, we
+    # convert it into the latter, and then we
+    # convert it into a dict of {infile:encoding}
+    # mappings
     if args.encoding is not None:
         if len(args.encoding) == 1:
-            args.encoding = args.encoding[0]
+            args.encoding = [args.encoding[0]] * len(args.infile)
         elif len(args.encoding) != len(args.infile):
             raise ValueError('Wrong number of encodings specified - specify '
                              'either one encoding, or one encoding for each '
                              'input file.')
+        args.encoding = dict(zip(args.infile, args.encoding))
 
     # turn loaders into dict of { absfile : name } mappings
     if args.loader is not None:
