@@ -164,3 +164,18 @@ def formatCompound(dtable, column, series, delim=','):
         return delim.join([str(v) for v in val])
 
     return series.apply(fmt)
+
+
+@custom.formatter('escapeString')
+def escapeString(dtable, column, series):
+    """Encodes every value of ``series`` as a string, with any escape
+    characters (``\\n``, ``\\t``, etc) formatted literally. This has the
+    effect that the series is coerced to a string type (if not already).
+    """
+    if len(series) == 0:
+        return series
+
+    def fmt(val):
+        return str(val).encode('unicode_escape').decode('utf-8')
+
+    return series.apply(fmt)
