@@ -15,9 +15,8 @@ import              fnmatch
 import              logging
 import              collections
 
-from .. import      expression
-from .. import      loadtables
-from .. import      fileinfo
+import funpack.expression as expression
+import funpack.loadtables as loadtables
 
 
 log = logging.getLogger(__name__)
@@ -59,18 +58,13 @@ def restrictVariables(cattable, variables, categories):
     return variables
 
 
-def columnsToLoad(datafiles,
-                  vartable,
-                  variables,
-                  colnames,
-                  indexes=None,
-                  sniffers=None):
+def columnsToLoad(fileinfo, vartable, variables, colnames):
     """Determines which columns should be loaded from ``datafiles``.
 
     Peeks at the first line of the data file (assumed to contain column names),
     then uses the variable table to determine which of them should be loaded.
 
-    :arg datafiles:     Path to data file(s)
+    :arg fileinfo:      :class:`.FileInfo` object describing the input file(s).
 
     :arg vartable:      Variable table
 
@@ -79,14 +73,6 @@ def columnsToLoad(datafiles,
     :arg colnames:      List of column names/glob-style wildcard patterns,
                         specifying columns to load.
 
-    :arg indexes:       Dict of ``{filename : [index]}`` mappings, specifying
-                        the position of the column(s) to use as the index.
-                        Defaults to 0 (the first column).
-
-    :arg sniffers:      Dict of ``{ file : snifferName }`` mappings containing
-                        custom sniffers to be used for specific files. See the
-                        :mod:`.custom` module.
-
     :returns:           A tuple containing:
 
                          - A dict of ``{ file : [Column] }`` mappings, the
@@ -98,21 +84,13 @@ def columnsToLoad(datafiles,
                            *ignore*.
     """
 
-    if sniffers is None: sniffers = {}
-    if indexes  is None: indexes  = {}
-
-    if isinstance(datafiles, str):
-        datafiles = [datafiles]
-
     # We apply these cleaning steps by
     # omitting the relevant columns.
     loadFuncNames = ['remove', 'keepVisits']
 
     # Peek at the columns that
     # are in the input files.
-    allcols = fileinfo.fileinfo(datafiles,
-                                indexes=indexes,
-                                sniffers=sniffers)[2]
+    allcols = [fileinfo.columns(df) for df in fileinfo.datafiles]
     ncols   = len(list(it.chain(*allcols)))
 
     # re-organise the columns - a list of
@@ -124,10 +102,6 @@ def columnsToLoad(datafiles,
     for col in it.chain(*allcols):
         byvid[col.vid].append(col)
 
-    # Build a full list of index
-    # columns for each data file.
-    indexes = [indexes.get(f, [0]) for f in datafiles]
-
     # retrieve all cleaning steps -
     # we are only going to apply the
     # cleaning steps that will
@@ -145,7 +119,7 @@ def columnsToLoad(datafiles,
     # mappings, and a list of columns
     # to drop.
     drop = []
-    load = collections.OrderedDict([(f, []) for f in datafiles])
+    load = collections.OrderedDict([(f, []) for f in fileinfo.datafiles])
     for vid, cols in byvid.items():
 
         # index column - load it!
@@ -359,13 +333,20 @@ def evaluateSubjectExpression(data, expr, cols):
     # to the expression evaluate method
     exprcols = {}
     for vid in vids:
-        exprcols[vid] = [c.name for c in cols[vid]]
+        vidcols = [c.name for c in cols[vid]]
+        if len(vidcols) > 0:
+            exprcols[vid] = vidcols
 
     if len(exprcols) == 0:
         log.debug('Ignoring expression (%s) - no associated '
                   'columns are present', str(expr))
         return None
 
+    if any(evid not in exprcols for evid in expr.variables):
+        log.warning('Cannot evaluate expression (%s) - one or '
+                    'more variables are not present', str(expr))
+        return None
+
     log.debug('Evaluating expression (%s) on columns %s',
               str(expr), list(it.chain(*exprcols.values())))
 
