@@ -46,10 +46,9 @@ import              collections
 import numpy  as np
 import pandas as pd
 
-from . import util
-from . import fileinfo
-from . import processing
-from . import expression
+import funpack.util       as util
+import funpack.processing as processing
+import funpack.expression as expression
 
 
 log = logging.getLogger(__name__)
@@ -352,7 +351,7 @@ call to :func:`addImplicitCategories`).
 """
 
 
-def loadTables(datafiles,
+def loadTables(fileinfo,
                varfiles=None,
                dcfiles=None,
                typefile=None,
@@ -361,7 +360,7 @@ def loadTables(datafiles,
                **kw):
     """Loads the data tables used to run ``funpack``.
 
-    :arg datafiles: Path(s) to the data files
+    :arg fileinfo:  :class:`.FileInfo` object describing the input data files.
     :arg varfiles:  Path to one or more partial variable table files
     :arg dcfiles:   Path to one or more partial data coding table files
     :arg typefile:  Path to the type table file
@@ -372,34 +371,37 @@ def loadTables(datafiles,
     and :func:`loadProcessingTable` functions.
 
     :returns:      A tuple containing:
+
                     - The variable table
                     - The processing table
                     - The category table
                     - List of :class:`.Column` objects representing columns
                       which were in the data file(s), but not in the variable
-                      table
+                      table.
                     - List of :class:`.Column` objects representing columns
-                      which are uncategorised, and do not have any cleaning or
-                      processing explicitly applied for them.
+                      which are uncategorised.
     """
 
-    vartable, unk, unc = loadVariableTable(datafiles,
-                                           varfiles,
-                                           dcfiles,
-                                           typefile,
-                                           **kw)
-    proctable          = loadProcessingTable(procfile, **kw)
-    cattable           = loadCategoryTable(catfile)
-    unc                = identifyUncategorisedVariables(vartable,
-                                                        proctable,
-                                                        cattable,
-                                                        unc)
+    vartable, unk, _ = loadVariableTable(fileinfo,
+                                         varfiles,
+                                         dcfiles,
+                                         typefile,
+                                         **kw)
+    proctable        = loadProcessingTable(procfile, **kw)
+    cattable         = loadCategoryTable(catfile)
+    unc              = identifyUncategorisedVariables(fileinfo, cattable)
+
+    # uncategorised should not contain unknown
+    unc = [c for c in unc if c not in unk]
+
+    # Add categorise for unknown/
+    # uncategorised variables
     addImplicitCategories(cattable, unk, unc)
 
     return vartable, proctable, cattable, unk, unc
 
 
-def loadVariableTable(datafiles,
+def loadVariableTable(fileinfo,
                       varfiles=None,
                       dcfiles=None,
                       typefile=None,
@@ -410,14 +412,13 @@ def loadVariableTable(datafiles,
                       clean=None,
                       typeClean=None,
                       globalClean=None,
-                      indexes=None,
-                      sniffers=None,
                       dropAbsent=True,
                       **kwargs):
     """Given variable table and datacoding table file names, builds and returns
     the variable table.
 
-    :arg datafiles:   Path(s) to the data files
+    :arg fileinfo:    :class:`.FileInfo` object describing the input data
+                      files.
 
     :arg varfiles:    Path(s) to one or more variable files
 
@@ -453,14 +454,6 @@ def loadVariableTable(datafiles,
                       variable-specific cleaning in the variable table,
                       or specified via ``clean`` or ``typeClean``.
 
-    :arg indexes:     Dict of ``{filename : [index]}`` mappings, specifying
-                      the number of the column to use as the index. Defaults
-                      to 0 (the first column).
-
-    :arg sniffers:    Dict of ``{ file : snifferName }`` mappings containing
-                      custom sniffers to be used for specific files. See the
-                      :mod:`.custom` module.
-
     :arg dropAbsent:  If ``True`` (the default), remove all variables from the
                       variable table which are not present in the data
                       file(s).
@@ -480,9 +473,6 @@ def loadVariableTable(datafiles,
                   table, but which did not have any cleaning rules specified.
     """
 
-    if sniffers is None: sniffers = {}
-    if indexes  is None: indexes  = {}
-
     if noBuiltins: varbase, dcbase = None, None
     else:          varbase, dcbase = loadTableBases()
 
@@ -519,20 +509,14 @@ def loadVariableTable(datafiles,
     dctable .index = dctable .index.astype(DCTABLE_DTYPES[  'ID'])
     tytable .index = tytable .index.astype(TYPETABLE_DTYPES['Type'])
 
-    # All column names and variable
-    # IDs in the input data files
-    finfo = fileinfo.fileinfo(datafiles,
-                              indexes=indexes,
-                              sniffers=sniffers)
-
-    # with the index column(s)
-    # from each file dropped
-    cols = list(finfo[2])
-    for i, df in enumerate(datafiles):
-        dfcols  = cols[i]
-        dfidx   = indexes.get(df, [0])
-        cols[i] = [c for c in dfcols if c.index not in dfidx]
-    cols = list(it.chain(*cols))
+    # Build a list of all columns in the input
+    # data files, with the index column(s)
+    # from each file dropped (index columns
+    # are assigned a VID of 0)
+    cols = []
+    for df in fileinfo.datafiles:
+        dfcols = fileinfo.columns(df)
+        cols.extend([c for c in dfcols if c.vid != 0])
 
     # Make sure the variable table
     # contains an entry for every
@@ -618,8 +602,8 @@ def loadVariableTable(datafiles,
             raise ValueError('Columns don\'t match [len({}) != '
                              'len({})]: {}'.format(val1, val2, row.name))
 
-    checkRecoding     = ft.partial(checkLengths, 'RawLevels', 'NewLevels')
-    checkParentValues = ft.partial(checkLengths, 'RawLevels', 'NewLevels')
+    checkRecoding     = ft.partial(checkLengths, 'RawLevels',    'NewLevels')
+    checkParentValues = ft.partial(checkLengths, 'ParentValues', 'ChildValues')
 
     vartable.apply(checkRecoding,     axis=1)
     vartable.apply(checkParentValues, axis=1)
@@ -645,6 +629,7 @@ def loadTableBases():
                          ``numpy`` data type (e.g. ``float32``).
 
     :returns: A tuple containing:
+
                - a ``pandas.DataFrame`` to be used as the base for the
                  variable table
                - a ``pandas.DataFrame`` to be used as the base for the
@@ -1154,8 +1139,7 @@ def addImplicitCategories(cattable, unknown, uncat):
                           FUNPACK variable information in ``funpack/data/``.
 
      - ``uncategorised``: Variables which are not present in any other
-                          category, and which do not have any cleaning/
-                          processing rules defined.
+                          category.
 
     :arg cattable: The category table.
     :arg unknown:  Sequence of :class:`.Column` objects representing
@@ -1230,45 +1214,29 @@ def columnTypes(vartable, columns):
     return vttypes, dtypes
 
 
-def identifyUncategorisedVariables(vartable,
-                                   proctable,
-                                   cattable,
-                                   unclean):
+def identifyUncategorisedVariables(fileinfo, cattable):
     """Called by :func:`loadTables`. Identifies all variables which are in the
-    data file(s), but which:
-
-     - are uncategorised (not present in any categories in the category table),
-       and
-     - did not have any cleaning/processing specifically applied to them or to
-       their data coding.
+    data file(s), but which are uncategorised (not present in any categories
+    in the category table).
 
     Such variables might have been overlooked, so the user may need to be
     warned about them.
 
-    :arg vartable:  Variable table
-    :arg proctable: Processing table
+    :arg fileinfo:  :class:`.FileInfo` object.
     :arg cattable:  Category table
-    :arg unclean:   List of :class:`.Column` objects represennting columns for
-                    which there were no cleaning rules specified. Generated by
-                    :func:`loadVariableTable`.
-    :returns:       A list of variables which are not in any category, and do
-                    not have any cleaning or processing rules applied.
+    :returns:       A list of :class:`.Column` objects associated with
+                    variables that are uncategorised.
     """
 
-    uncategorised = []
-
     def isCategorised(col):
         def inCategory(catvars):
             return col.vid in catvars
         return cattable['Variables'].apply(inCategory).any()
 
-    def isProcessed(col):
-        def inProcess(procvars):
-            return isinstance(procvars, list) and col.vid in procvars
-        return proctable['Variable'].apply(inProcess).any()
-
-    for c in unclean:
-        if not (isCategorised(c) or isProcessed(c)):
-            uncategorised.append(c)
+    uncategorised = []
+    for datafile in fileinfo.datafiles:
+        cols = fileinfo.columns(datafile)
+        cols = [c for c in cols if (c.vid != 0) and (not isCategorised(c))]
+        uncategorised.extend(cols)
 
     return uncategorised
