@@ -25,6 +25,7 @@ import funpack.icd10       as icd10
 import funpack.config      as config
 import funpack.custom      as custom
 import funpack.dryrun      as dryrun
+import funpack.fileinfo    as fileinfo
 import funpack.cleaning    as cleaning
 import funpack.datatable   as datatable
 import funpack.exporting   as exporting
@@ -156,10 +157,16 @@ def doImport(args, mgr):
                   each input file.
     """
 
+    finfo = fileinfo.FileInfo(args.infile,
+                              indexes=args.index,
+                              loaders=args.loader,
+                              encodings=args.encoding,
+                              renameDuplicates=args.rename_duplicates)
+
     with util.timed('Table import', log):
         vartable, proctable, cattable, unknowns, uncategorised = \
             loadtables.loadTables(
-                args.infile,
+                finfo,
                 args.variable_file,
                 args.datacoding_file,
                 args.type_file,
@@ -174,9 +181,7 @@ def doImport(args, mgr):
                 globalClean=args.global_clean,
                 skipProcessing=args.skip_processing,
                 prependProcess=args.prepend_process,
-                appendProcess=args.append_process,
-                sniffers=args.loader,
-                indexes=args.index)
+                appendProcess=args.append_process)
 
     subjects, exprs = args.subject
     variables       = args.variable
@@ -186,7 +191,7 @@ def doImport(args, mgr):
     # Import data
     with util.timed('Data import', log):
         dtable, drop = importing.importData(
-            datafiles=args.infile,
+            fileinfo=finfo,
             vartable=vartable,
             proctable=proctable,
             cattable=cattable,
@@ -196,14 +201,11 @@ def doImport(args, mgr):
             subjects=subjects,
             subjectExprs=exprs,
             exclude=args.exclude,
-            encoding=args.encoding,
-            indexes=args.index,
             trustTypes=args.trust_types,
             mergeAxis=args.merge_axis,
             mergeStrategy=args.merge_strategy,
             indexVisits=args.index_visits,
             dropNaRows=args.drop_na_rows,
-            loaders=args.loader,
             njobs=args.num_jobs,
             mgr=mgr,
             dryrun=args.dry_run)
@@ -231,8 +233,7 @@ def doImport(args, mgr):
                         u.name, u.datafile, u.index, u.vid)
         for u in uncategorised:
             log.warning('Variable %s [file %s, column %s, assigned '
-                        'variable ID %s] is uncategorised and does not '
-                        'have any cleaning or processing rules set.',
+                        'variable ID %s] is uncategorised.',
                         u.name, u.datafile, u.index, u.vid)
 
     return dtable, unknowns, uncategorised, drop
@@ -385,6 +386,7 @@ def doExport(dtable, args):
                 formatters=args.var_format,
 
                 # TSV options
+                escapeNewlines=args.escape_newlines,
                 sep=args.tsv_sep,
                 missingValues=args.tsv_missing_values,
 
