@@ -286,7 +286,23 @@ def _pairwiseRemoveIfRedundant(dtable, data, corrthres, nathres=None):
     return redundant
 
 
-@custom.processor(auxvids=['take'])
+# auxvids tells the processing runner the
+# "take" argument refers to other variables
+# which are not processed, but are needed
+# to perform the processing.
+#
+# "filterMissing" tells the processing
+# runner *not* to remove variables which
+# are not present in the data from the list
+# of vids that are passed in - we do our
+# own check here.
+#
+# Both of the above are ridiculous hacks
+# which are in place because this function,
+# and FUNPACK, used to parallelise things
+# differently, and to preserve backwards
+# compatibility.
+@custom.processor(auxvids=['take'], filterMissing=False)
 def binariseCategorical(dtable,
                         vids,
                         acrossVisits=False,
@@ -391,6 +407,8 @@ def binariseCategorical(dtable,
     if nameFormat is None:
         nameFormat = defaultNameFormat[acrossVisits, acrossInstances]
 
+    # if take is a single vid or None,
+    # we turn it into [take] * len(vids)
     if not isinstance(take, collections.Sequence):
         take = [take] * len(vids)
 
@@ -406,6 +424,13 @@ def binariseCategorical(dtable,
 
     for vid, takevid in zip(vids, take):
 
+        if (not dtable.present(vid)) or \
+           (takevid is not None and not dtable.present(takevid)):
+            log.warning('Variable %u (or take: %s) is not present in the '
+                        'data set - skipping the binariseCategorical step',
+                        vid, takevid)
+            continue
+
         colgrps = gatherColumnGroups(vid)
 
         if takevid is None: takegrps = [None] * len(colgrps)
