@@ -85,7 +85,7 @@ def isSparse(
 
     :arg minstd:   Minimum standard deviation, for numeric/categorical types.
 
-    :arg mincat:   Minimum size/proportion of largest category,
+    :arg mincat:   Minimum size/proportion of smallest category,
                    for integer/categorical types.
 
     :arg maxcat:   Maximum size/proportion of largest category,
@@ -487,8 +487,9 @@ def binariseCategorical(
         dtype = take.dtypes[0]
         take  = take.to_numpy()
 
-        if np.issubdtype(dtype, np.integer): fill = 0
-        else:                                fill = np.nan
+        if   np.issubdtype(dtype, np.integer):    fill = 0
+        elif np.issubdtype(dtype, np.datetime64): fill = np.datetime64('NAT')
+        else:                                     fill = np.nan
 
     # We parallelise binarisation across
     # blocks of unique values - each call
@@ -507,11 +508,13 @@ def binariseCategorical(
     # If take is None, bindata is a uint8
     # array; otherwise it is a take.dtype
     # array.  If take has a dtype of
-    # np.datetime64, we need a hack, as
-    # we can't create a sharedmem array
-    # of that type. So for datetime, we
-    # make bindata uint64, and then cast
-    # it to datetime64 afterwards.
+    # np.datetime64, we need a hack, as we
+    # can't create a sharedmem array of that
+    # type (it is not supported by
+    # numpy.ctypeslib.as_ctypes_type). So
+    # for datetime, we make bindata uint64,
+    # and then cast it back to datetime64
+    # afterwards.
     if np.issubdtype(dtype, np.datetime64):
         cdtype = np.uint64
     else:
@@ -568,6 +571,7 @@ def generateBinaryColumns(offset, nvals, fill, token):
 
     The following arguments are passed internally from
     :func:`binariseCategorical` to this function:
+
      - Sequence of unique values
      - Numpy array containing the data
      - Numpy array to store the output
