@@ -24,6 +24,7 @@ import pandas as pd
 
 import funpack.util       as util
 import funpack.custom     as custom
+import funpack.fileinfo   as fileinfo
 import funpack.loadtables as loadtables
 import funpack.datatable  as datatable
 
@@ -224,9 +225,8 @@ def gen_tables(variables, vtypes=None, datafiles=None):
 
                         f.write(tmpl.format(variable=v, type=vtype) + '\n')
 
-
         vt, pt, ct, uk, up = loadtables.loadTables(
-            datafiles,
+            fileinfo.FileInfo(datafiles),
             ['variables.tsv'],
             ['datacodings.tsv'],
             'types.tsv',
