@@ -23,6 +23,7 @@ import funpack.cleaning as cleaning
 import funpack.custom as custom
 import funpack.cleaning_functions as cfns
 
+import funpack.fileinfo  as fileinfo
 import funpack.importing as importing
 import funpack.hierarchy as hierarchy
 
@@ -42,8 +43,8 @@ def test_keepVisits():
 
         gen_test_data(10, 20, 'data.txt', max_visits=10, start_var=50)
         vartable, proctable, cattable, _ = gen_tables(range(50, 60))
-
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable)
@@ -79,7 +80,8 @@ def test_keepVisits_not_instancing_2():
         vartable.loc[1, 'Instancing'] = 2
         vartable.loc[2, 'Instancing'] = 0
 
-        dt, _ = importing.importData('data.tsv', vartable, proctable, cattable)
+        finfo = fileinfo.FileInfo('data.tsv')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         v1cols = dt.columns(1)
         v2cols = dt.columns(2)
@@ -142,7 +144,8 @@ def test_fillVisits():
 
         for method in ['mean', 'mode']:
 
-            dt, _ = importing.importData('data.txt',
+            finfo = fileinfo.FileInfo('data.txt')
+            dt, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable,
@@ -191,7 +194,8 @@ def test_fillMissing():
 
         vartable, proctable, cattable, _ = gen_tables([1])
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable,
@@ -225,7 +229,8 @@ def test_codeToNumeric():
 
         vartable.loc[1, 'DataCoding'] = hierarchy.HIERARCHY_DATA_NAMES['opcs3']
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable)
@@ -260,7 +265,8 @@ def test_makeNa():
             np.savetxt(f, data, delimiter='\t')
         vartable, proctable, cattable, _ = gen_tables([1, 2])
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable,
@@ -292,7 +298,7 @@ def test_applyNewLevels():
 
     codes1 = np.random.randint(100, 200, 10)
     codes2 = np.random.randint(100, 200, 10)
-    codes3 = list(reversed(range(10)))
+    codes3 = np.arange(9, -1, -1)
 
     exp1 = [codes1[data[i, 1]] for i in range(50)]
     exp2 = [codes2[data[i, 2]] for i in range(50)]
@@ -302,11 +308,11 @@ def test_applyNewLevels():
 
     with warnings.catch_warnings():
         warnings.simplefilter('ignore')
-        vartable['RawLevels'][1] = list(range(10))
+        vartable['RawLevels'][1] = np.arange(10)
         vartable['NewLevels'][1] = codes1
-        vartable['RawLevels'][2] = list(range(10))
+        vartable['RawLevels'][2] = np.arange(10)
         vartable['NewLevels'][2] = codes2
-        vartable['RawLevels'][3] = list(range(10))
+        vartable['RawLevels'][3] = np.arange(10)
         vartable['NewLevels'][3] = codes3
 
 
@@ -318,7 +324,8 @@ def test_applyNewLevels():
             f.write('\t'.join(cols) + '\n')
             np.savetxt(f, data, delimiter='\t')
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable)
@@ -340,8 +347,8 @@ def test_applyNAInsertion():
     data       = np.random.randint(0, 10, (100, 3)).astype(np.float32)
     data[:, 0] = np.arange(1, 101)
 
-    miss1 = list(np.random.choice(range(10), 4, replace=False))
-    miss2 = list(np.random.choice(range(10), 4, replace=False))
+    miss1 = np.random.choice(range(10), 4, replace=False)
+    miss2 = np.random.choice(range(10), 4, replace=False)
 
     exp1 = data[:, 1].copy()
     exp2 = data[:, 2].copy()
@@ -355,7 +362,7 @@ def test_applyNAInsertion():
         warnings.simplefilter("ignore")
         vartable['NAValues'][1] = miss1
         vartable['NAValues'][2] = miss2
-        vartable['NAValues'][3] = [1, 2, 3]
+        vartable['NAValues'][3] = np.array([1, 2, 3])
 
     cols = ['eid', '1-0.0', '2-0.0']
 
@@ -366,7 +373,8 @@ def test_applyNAInsertion():
             f.write('\t'.join(cols) + '\n')
             np.savetxt(f, data, delimiter='\t')
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable,
@@ -450,7 +458,8 @@ def test_applyChildValues():
         vartable.loc[cvals.keys(), 'ChildValues'] = \
             [lt.convert_comma_sep_numbers(v) for v in cvals.values()]
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable,
@@ -503,7 +512,8 @@ def test_applyCleaningFunctions():
         vartable.loc[(3, ), 'Clean'] = (lt.convert_Process(
             'cleaner', 'proc2(50)'), )
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable,
@@ -535,7 +545,8 @@ def test_cleanData():
             f.write('\t'.join(cols) + '\n')
             np.savetxt(f, data, delimiter='\t')
         vartable, proctable, cattable, _ = gen_tables([1, 2])
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable,
@@ -574,7 +585,8 @@ def test_parseSpirometryData():
         mgr = mp.Manager()
         vartable, proctable, cattable, _ = gen_tables([1, 2])
 
-        dt, _ = importing.importData('data.txt',
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo,
                                      vartable,
                                      proctable,
                                      cattable,
@@ -643,7 +655,8 @@ def test_flattenHierarchical():
 
         for level, exp in tests:
 
-            dt, _ = importing.importData('data.txt',
+            finfo = fileinfo.FileInfo('data.txt')
+            dt, _ = importing.importData(finfo,
                                          vartable,
                                          proctable,
                                          cattable,
