@@ -26,6 +26,7 @@ import funpack.exporting      as exporting
 import funpack.exporting_hdf5 as exporting_hdf5
 import funpack.exporting_tsv  as exporting_tsv
 import funpack.datatable      as datatable
+import funpack.fileinfo       as fileinfo
 import funpack.custom         as custom
 import funpack.util           as util
 
@@ -344,7 +345,8 @@ def test_compound():
             f.write(data)
 
         vartable, proctable, cattable, _ = gen_tables([1, 2])
-        dt, _ = importing.importData('data.txt', vartable, proctable, cattable)
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         dt[:, '1-0.0'] = dt[:, '1-0.0'].apply(parseCompound)
 
@@ -381,7 +383,8 @@ def test_exporting_id_column():
             f.write(data)
 
         vartable, proctable, cattable, _ = gen_tables([1], datafiles=['data.txt'])
-        dt, _ = importing.importData('data.txt', vartable, proctable, cattable)
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         exporting.exportData(dt,
                              'out.txt',
@@ -408,8 +411,9 @@ def test_exporting_no_data():
             f.write(data)
 
         vartable, proctable, cattable, _ = gen_tables([1])
+        finfo = fileinfo.FileInfo('data.txt')
         dt, _ = importing.importData(
-            'data.txt', vartable, proctable, cattable, variables=[3])
+            finfo, vartable, proctable, cattable, variables=[3])
 
         with pytest.raises(RuntimeError):
             exporting.exportData(dt,
@@ -435,8 +439,9 @@ def test_exportTSV_parallel():
             np.savetxt(f, data, fmt='%i', delimiter='\t')
 
         vartable, proctable, cattable, _ = gen_tables(range(1, ncols + 1))
+        finfo = fileinfo.FileInfo('data.txt')
         dt, _ = importing.importData(
-            'data.txt', vartable, proctable, cattable)
+            finfo, vartable, proctable, cattable)
 
         # in one go, single process
         exporting_tsv.exportTSV(dt,
@@ -468,3 +473,41 @@ def test_exportTSV_parallel():
         eq(got1)
         eq(got2)
         eq(got3)
+
+
+def test_exportCSV_escapeNewlines():
+
+    data = tw.dedent("""
+    eid,1-0.0,2-0.0
+    1,"a b c
+    d e f",abc
+    2,one two three,"four five
+    six seven"
+    3,"x y	z","a b
+
+    cde"
+    """).strip()
+
+    exp = tw.dedent(r"""
+    eid,1-0.0,2-0.0
+    1,a b c\nd e f,abc
+    2,one two three,four five\nsix seven
+    3,x y\tz,a b\n\ncde
+    """).strip()
+
+    with tempdir():
+
+        with open('in.csv', 'wt') as f:
+            f.write(data)
+
+        vartable, proctable, cattable, _ = gen_tables([1, 2])
+        finfo = fileinfo.FileInfo('in.csv')
+        dt, _ = importing.importData(
+            finfo, vartable, proctable, cattable)
+
+        exporting_tsv.exportCSV(dt, 'out.csv', sep=',', escapeNewlines=True)
+
+        with open('out.csv', 'rt') as f:
+            got = f.read()
+
+        assert got.strip() == exp
