@@ -18,7 +18,7 @@ import funpack.util           as util
 import funpack.custom         as custom
 import funpack.fileinfo       as fileinfo
 
-from . import tempdir, gen_tables, gen_test_data
+from funpack.tests import tempdir, gen_tables
 
 
 def test_loadFiles():
@@ -33,13 +33,14 @@ def test_loadFiles():
                 f.write('{}, {}, {}\n'.format(i, *d))
             f.write('11, 54, abcde\n')
 
-        cols = fileinfo.fileinfo('data.txt')[2][0]
-        cols = {'data.txt' : cols}
+        finfo = fileinfo.FileInfo('data.txt')
+
+        cols = {'data.txt' : finfo.columns('data.txt')}
 
         vartable.loc[10,  'Type'] = util.CTYPES.integer
         vartable.loc[100, 'Type'] = util.CTYPES.continuous
 
-        loaded = core.loadFiles('data.txt', vartable, cols)[0]
+        loaded = core.loadFiles(finfo, vartable, cols)[0]
         got10  = loaded['10-0.0'].values
         got100 = loaded['100-0.0'].values
 
@@ -73,10 +74,11 @@ def test_loadFiles_multiple_files_cols():
                 for ri, c in enumerate(d):
                     f.write('{}, {}, {}\n'.format(ri, *c))
 
-        cols    = fileinfo.fileinfo(dfiles)[2]
-        coldict = {f : c for f, c in zip(dfiles, cols)}
+        finfo   = fileinfo.FileInfo(dfiles)
+        cols    = [finfo.columns(f) for f in dfiles]
+        coldict = dict(zip(dfiles, cols))
 
-        loaded, lcols = core.loadFiles(dfiles, vartable, coldict)
+        loaded, lcols = core.loadFiles(finfo, vartable, coldict)
 
         assert lcols == cols[0] + cols[1][1:]
 
@@ -102,11 +104,12 @@ def test_loadFiles_multiple_files_rows():
                 for ri, c in enumerate(d):
                     f.write('{}, {}, {}\n'.format(10 * fi + ri, *c))
 
-        cols    = fileinfo.fileinfo(dfiles)[2]
-        coldict = {f : c for f, c in zip(dfiles, cols)}
+        finfo   = fileinfo.FileInfo(dfiles)
+        cols    = [finfo.columns(f) for f in dfiles]
+        coldict = dict(zip(dfiles, cols))
 
         loaded, lcols = core.loadFiles(
-            dfiles, vartable, coldict, mergeAxis='subjects')
+            finfo, vartable, coldict, mergeAxis='subjects')
 
         assert lcols == cols[0]
         assert np.all(loaded['10-0.0'] ==
@@ -133,7 +136,8 @@ def test_loadFiles_indexes_cols():
                 f.write('{}, {}, {}\n'.format(c[0], c[1], ri))
 
         idxdict = {'data0.txt' : [1], 'data1.txt' : [2]}
-        cols    = fileinfo.fileinfo(dfiles, indexes=idxdict)[2]
+        finfo   = fileinfo.FileInfo(dfiles, indexes=idxdict)
+        cols    = [finfo.columns(f) for f in dfiles]
         coldict = {}
 
         # loadFiles expects the first
@@ -141,8 +145,7 @@ def test_loadFiles_indexes_cols():
         coldict['data0.txt'] = cols[0]
         coldict['data1.txt'] = cols[1]
 
-        loaded, lcols = core.loadFiles(
-            dfiles, vartable, coldict, indexes=idxdict)
+        loaded, lcols = core.loadFiles(finfo, vartable, coldict)
 
         assert lcols == [cols[0][1], cols[0][0], cols[0][2],
                          cols[1][0], cols[1][1]]
@@ -171,15 +174,15 @@ def test_loadFiles_indexes_rows():
                 f.write('{}, {}, {}\n'.format(c[0], c[1], 10 * 1 + ri))
 
         idxdict = {'data0.txt' : [1], 'data1.txt' : [2]}
-        cols    = fileinfo.fileinfo(dfiles, indexes=idxdict)[2]
+        finfo   = fileinfo.FileInfo(dfiles, indexes=idxdict)
+        cols    = [finfo.columns(f) for f in dfiles]
         coldict = {}
 
         coldict['data0.txt'] = cols[0]
         coldict['data1.txt'] = cols[1]
 
         loaded, lcols = core.loadFiles(
-            dfiles, vartable, coldict,
-            indexes=idxdict,
+            finfo, vartable, coldict,
             mergeAxis='subjects')
 
         assert lcols == [cols[0][1], cols[0][0], cols[0][2]]
@@ -201,11 +204,11 @@ def test_loadFiles_subjects_exclude():
             for ri, c in enumerate(data):
                 f.write('{}, {}, {}\n'.format(ri+1, c[0], c[1]))
 
-        cols    = fileinfo.fileinfo([dfile])[2][0]
-        coldict = {}
+        finfo   = fileinfo.FileInfo([dfile])
+        cols    = finfo.columns(dfile)
 
         loaded, lcols = core.loadFiles(
-            [dfile], vartable, {dfile : cols},
+            finfo, vartable, {dfile : cols},
             subjects=np.arange(1, 10),
             exclude=np.arange(5, 11))
 
@@ -214,7 +217,6 @@ def test_loadFiles_subjects_exclude():
 
 
 
-
 def test_importData_indexes():
     """
     """
@@ -250,14 +252,18 @@ def test_importData_indexes():
         with open('data1.txt', 'wt') as f: f.write(data1)
         with open('data2.txt', 'wt') as f: f.write(data2)
 
+        # check that loaded column order matches
+        # order in which input files are specified
+        idxdict = {'data1.txt' : [1]}
+        finfo1  = fileinfo.FileInfo(['data1.txt', 'data2.txt'],
+                                     indexes=idxdict)
+        finfo2  = fileinfo.FileInfo(['data2.txt', 'data1.txt'],
+                                     indexes=idxdict)
+
         loaded1, _ = importing.importData(
-            ['data1.txt', 'data2.txt'],
-            vartable, proctable, cattable,
-            indexes={'data1.txt' : [1]})
-        loaded2, _ = importing.importData(
-            ['data2.txt', 'data1.txt'],
-            vartable, proctable, cattable,
-            indexes={'data1.txt' : [1]})
+            finfo1, vartable, proctable, cattable)
+        loaded2, _ = importing.importData(finfo2,
+            vartable, proctable, cattable)
 
         loaded1 = loaded1[:, :]
         loaded2 = loaded2[:, :]
@@ -295,12 +301,13 @@ def test_importData_non0_index_with_dropped_columns():
 
         indexes = {'data.txt' : [2]}
 
+        finfo = fileinfo.FileInfo('data.txt', indexes=indexes)
+
         loaded, _ = importing.importData(
-            ['data.txt'], vartable, proctable, cattable,
-            indexes=indexes,
+            finfo, vartable, proctable, cattable,
             variables=[2, 4])
 
-        allcols = fileinfo.fileinfo('data.txt', indexes=indexes)[2][0]
+        allcols = finfo.columns('data.txt')
         expcols = [allcols[2], allcols[1], allcols[4]]
 
         assert loaded.allColumns == expcols
@@ -321,14 +328,13 @@ def test_importData():
             # bad data should be interpreted as nan
             f.write('11, 54, abcde\n')
 
-        cols = fileinfo.fileinfo('data.txt')[2][0]
-        cols = {'data.txt' : cols}
+        finfo = fileinfo.FileInfo('data.txt')
+        cols = {'data.txt' : finfo.columns('data.txt')}
 
         vartable.loc[10,  'Type'] = util.CTYPES.integer
         vartable.loc[100, 'Type'] = util.CTYPES.continuous
 
-        loaded, _ = importing.importData(
-            'data.txt', vartable, proctable, cattable)
+        loaded, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         assert loaded.allColumns == cols['data.txt']
         got10  = loaded[:, '10-0.0']
@@ -358,10 +364,11 @@ def test_importData_dropped():
             for i, d in enumerate(data):
                 f.write('{}, {}, {}, {}\n'.format(i, *d))
 
-        cols = fileinfo.fileinfo('data.txt')[2][0]
+        finfo = fileinfo.FileInfo('data.txt')
+        cols  = finfo.columns('data.txt')
 
         loaded, dropped = importing.importData(
-            'data.txt', vartable, proctable, cattable, variables=[1, 3])
+            finfo, vartable, proctable, cattable, variables=[1, 3])
 
         assert dropped           == [cols[2]]
         assert loaded.allColumns == [cols[0]] + cols[1::2]
@@ -389,27 +396,30 @@ def test_encoding():
             with open('data.txt', 'wt', encoding=enc) as f:
                 f.write(data)
 
-        df_enc, _ = importing.importData(
-            'data.txt',
-            vartable,
-            proctable,
-            cattable,
-            encoding=enc)
-        assert df_enc[1, '1-0.0'] == val
-        del df_enc
-        df_enc = None
+            encodings = {'data.txt' : enc}
+            finfo     = fileinfo.FileInfo('data.txt', encodings=encodings)
 
-        # ascii/latin1 should load ok without
-        # us having to specify the encoding
-        if enc in ('ascii', 'latin1'):
-            df_noenc, _ = importing.importData(
-                'data.txt',
+            df_enc, _ = importing.importData(
+                finfo,
                 vartable,
                 proctable,
                 cattable)
-            assert df_noenc[1, '1-0.0'] == val
-            del df_noenc
-            df_noenc = None
+            assert df_enc[1, '1-0.0'] == val
+            del df_enc
+            df_enc = None
+
+            # ascii/latin1 should load ok without
+            # us having to specify the encoding
+            if enc in ('ascii', 'latin1'):
+                finfo       = fileinfo.FileInfo('data.txt')
+                df_noenc, _ = importing.importData(
+                    finfo,
+                    vartable,
+                    proctable,
+                    cattable)
+                assert df_noenc[1, '1-0.0'] == val
+                del df_noenc
+                df_noenc = None
 
 
 def test_importData_nonnumeric_looks_like_numeric():
@@ -427,20 +437,18 @@ def test_importData_nonnumeric_looks_like_numeric():
             # make sure leading zeros are preserved
             f.write('11, 0029\n')
 
-        cols = fileinfo.fileinfo('data.txt')[2][0]
-        cols = {'data.txt' : cols}
+        finfo = fileinfo.FileInfo('data.txt')
 
         vartable.loc[100, 'Type'] = util.CTYPES.text
 
         exp = [str(v) for v in data] + ['0029']
 
         loaded, _ = importing.importData(
-            'data.txt', vartable, proctable, cattable)
+            finfo, vartable, proctable, cattable)
         assert (loaded[:, '100-0.0'] == exp).all()
 
         loaded, _ = importing.importData(
-            'data.txt', vartable, proctable, cattable,
-            trustTypes=True)
+            finfo, vartable, proctable, cattable, trustTypes=True)
         assert (loaded[:, '100-0.0'] == exp).all()
 
 
@@ -459,9 +467,8 @@ def test_loadFile_parallel():
             f.write('\t'.join(colnames) + '\n')
             np.savetxt(f, data, fmt='%i', delimiter='\t')
 
-        info    = fileinfo.fileinfo('data.txt')
-        dialect = info[0][0]
-        cols    = info[2][0]
+        finfo = fileinfo.FileInfo('data.txt')
+        cols  = finfo.columns('data.txt')
 
         exp = pd.DataFrame(data[:, 1:],
                            index=data[:, 0],
@@ -471,20 +478,16 @@ def test_loadFile_parallel():
         # loaded in one go
         got1 = core.loadFile(
             'data.txt',
+            finfo,
             vartable,
-            True,
-            dialect,
-            cols,
             cols,
             nrows=100000)[0]
 
         # loaded in chunks in a single process
         got2 = core.loadFile(
             'data.txt',
+            finfo,
             vartable,
-            True,
-            dialect,
-            cols,
             cols,
             nrows=9987)[0]
 
@@ -493,10 +496,8 @@ def test_loadFile_parallel():
         with mp.Pool(8) as pool:
             got3 = core.loadFile(
                 'data.txt',
+                finfo,
                 vartable,
-                True,
-                dialect,
-                cols,
                 cols,
                 nrows=9987,
                 pool=pool)[0]
@@ -522,10 +523,8 @@ def test_loadFile_parallel():
         with mp.Pool(8) as pool:
             got = core.loadFile(
                 'data.txt',
+                finfo,
                 vartable,
-                True,
-                dialect,
-                cols,
                 cols,
                 subjects=include,
                 subjectExprs=exprs,
@@ -567,8 +566,69 @@ def test_importData_dropNaRows():
         with open('data.txt', 'wt') as f:
             f.write(data)
 
+        finfo = fileinfo.FileInfo('data.txt')
         loaded, _ = importing.importData(
-            ['data.txt'], vartable, proctable, cattable,
-            dropNaRows=True)
+            finfo, vartable, proctable, cattable, dropNaRows=True)
 
         assert list(loaded.index) == [1, 3, 4, 5, 6, 8, 10]
+
+
+def test_importData_duplicate_columns():
+
+    data       = np.random.randint(1, 100, (10, 3))
+    data[:, 0] = np.arange(1, 10 + 1)
+    colnames   = ['eid'] + ['1-0.0', '1-0.0']
+
+    vartable, proctable, cattable = gen_tables([1])[:3]
+
+    custom.registerBuiltIns()
+
+    with tempdir():
+        with open('data.txt', 'wt') as f:
+            f.write('\t'.join(colnames) + '\n')
+            np.savetxt(f, data, fmt='%i', delimiter='\t')
+
+        finfo     = fileinfo.FileInfo('data.txt', renameDuplicates=True)
+        dtable, _ = importing.importData(finfo, vartable, proctable, cattable)
+
+        cols = dtable.dataColumns
+
+        assert dtable.variables == [0, 1]
+        assert [c.name     for c in cols] == ['1-0.0', '1-0.0.1']
+        assert [c.origname for c in cols] == ['1-0.0', '1-0.0']
+        assert (dtable[:, :] == data[:, 1:]).all().all()
+
+
+def test_importData_duplicate_columns_multiple_files():
+    """
+    """
+    data       = np.random.randint(1, 100, (10, 5))
+    data[:, 0] = np.arange(1, 10 + 1)
+    colnames1  = ['eid'] + ['1-0.0', '2-0.0']
+    colnames2  = ['eid'] + ['2-0.0', '3-0.0']
+
+    vartable, proctable, cattable = gen_tables([1, 2, 3])[:3]
+
+    custom.registerBuiltIns()
+
+    with tempdir():
+        with open('data1.txt', 'wt') as f:
+            f.write('\t'.join(colnames1) + '\n')
+            np.savetxt(f, data[:, [0, 1, 2]], fmt='%i', delimiter='\t')
+
+        with open('data2.txt', 'wt') as f:
+            f.write('\t'.join(colnames2) + '\n')
+            np.savetxt(f, data[:, [0, 3, 4]], fmt='%i', delimiter='\t')
+
+        finfo     = fileinfo.FileInfo(['data1.txt', 'data2.txt'],
+                                      renameDuplicates=True)
+        dtable, _ = importing.importData(finfo, vartable, proctable, cattable)
+
+        cols      = dtable.dataColumns
+        names     = sorted([c.name     for c in cols])
+        orignames = sorted([c.origname for c in cols])
+
+        assert dtable.variables == [0, 1, 2, 3]
+        assert names     == ['1-0.0', '2-0.0', '2-0.0.1', '3-0.0']
+        assert orignames == ['1-0.0', '2-0.0', '2-0.0',   '3-0.0']
+        assert (dtable[:, names] == data[:, 1:]).all().all()
