@@ -36,16 +36,17 @@ def test_columnsToLoad():
         with open('data.txt', 'wt') as f:
             f.write(data)
 
-        cols = fileinfo.fileinfo(['data.txt'])[2][0]
+        finfo = fileinfo.FileInfo('data.txt')
+        cols  = finfo.columns('data.txt')
 
-        gc, gd = filter.columnsToLoad(['data.txt'],
+        gc, gd = filter.columnsToLoad(finfo,
                                       vartable,
                                       None,
                                       None)
         assert gc['data.txt'] == cols
         assert gd             == []
 
-        gc, gd = filter.columnsToLoad(['data.txt'],
+        gc, gd = filter.columnsToLoad(finfo,
                                       vartable,
                                       [1, 2, 3],
                                       None)
@@ -54,8 +55,6 @@ def test_columnsToLoad():
         assert gd             == []
 
 
-
-
 def test_filterSubjects():
 
     data       = np.random.randint(1, 10, (500, 11))
@@ -180,3 +179,20 @@ def test_filterSubjects_multiple_columns():
     exp = any(data[:, :3] > 6) | any(data[:, 3:] < 4)
     got = filter.filterSubjects(df, cols, subjectExprs=exprs)
     assert (got.index == (np.where(exp)[0] + 1)).all()
+
+
+def test_filter_subjects_column_not_present():
+    data       = np.random.randint(1, 10, (500, 11))
+    index      = np.arange(1, 501)
+    data[:, 0] = index
+    colnames   = ['eid'] + ['{}-0.0'.format(i+1) for i in range(10)]
+    cols       = [Column(None, n, i, i) for i, n in enumerate(colnames)]
+    df         = pd.DataFrame(data, columns=colnames).set_index('eid')
+
+    # expression is skipped if any variable is not present
+    got1       = filter.filterSubjects(df, cols, subjectExprs=['v11 > 0'])
+    got2       = filter.filterSubjects(df, cols, subjectExprs=['v9  < 0 || '
+                                                               'v11 > 0'])
+
+    assert (got1 == df).all().all()
+    assert (got2 == df).all().all()
