@@ -14,6 +14,7 @@ import numpy  as np
 
 import funpack.datatable as datatable
 import funpack.loadtables as loadtables
+import funpack.fileinfo as fileinfo
 import funpack.util as util
 import funpack.custom as custom
 import funpack.processing_functions as pfns
@@ -71,7 +72,12 @@ def _prepare_variableTable(tdir, idxcol=0):
     with open(fdcs,   'wt') as f: f.write(dcdata)
     with open(ftypes, 'wt') as f: f.write(typedata)
 
-    return fdata, fvars, fdcs, ftypes
+    if idxcol != 0: indexes = {fdata : [idxcol]}
+    else:           indexes = None
+
+    finfo = fileinfo.FileInfo([fdata], indexes=indexes)
+
+    return finfo, fvars, fdcs, ftypes
 
 
 @clear_plugins
@@ -112,9 +118,9 @@ def test_loadTables():
         with open('proctable.tsv', 'wt') as f:
             f.write(procdata)
 
-        fdata, fvars, fdcs, ftypes = _prepare_variableTable(td)
+        finfo, fvars, fdcs, ftypes = _prepare_variableTable(td)
         vartable, proctable, cattable, unknowns, unprocessed = \
-            loadtables.loadTables([fdata],
+            loadtables.loadTables(finfo,
                                   [fvars],
                                   [fdcs],
                                   ftypes,
@@ -151,9 +157,9 @@ def test_loadVariableTable_standard():
     custom.registerBuiltIns()
 
     with tempdir() as td, patch_base_tables():
-        fdata, fvars, fdcs, ftypes = _prepare_variableTable(td)
+        finfo, fvars, fdcs, ftypes = _prepare_variableTable(td)
         vartable, unk, unp = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes)
+            finfo, [fvars], [fdcs], ftypes)
 
     expvids       = [1, 2, 5, 6, 99]
     exptypes      = [util.CTYPES.integer, util.CTYPES.continuous,
@@ -201,16 +207,12 @@ def test_loadVariableTable_standard():
 
 def test_loadVariableTable_indexes():
 
-
     custom.registerBuiltIns()
 
     with tempdir() as td:
-        fdata, fvars, fdcs, ftypes = _prepare_variableTable(td, 2)
+        finfo, fvars, fdcs, ftypes = _prepare_variableTable(td, 2)
         vartable, unk, unp = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes, indexes={fdata : [2]})
-
-        print()
-        print(open(fdata).read())
+            finfo, [fvars], [fdcs], ftypes)
 
     expvids  = [1, 2, 5, 6, 99]
     expdescs = ['var 1', 'var 2', 'var 5', 'var 6', '99-0.0']
@@ -230,19 +232,19 @@ def test_loadVariableTable_clean():
     customGlobalClean = 'codeToNumeric(name="icd10")'
 
     with tempdir() as td:
-        fdata, fvars, fdcs, ftypes = _prepare_variableTable(td)
+        finfo, fvars, fdcs, ftypes = _prepare_variableTable(td)
         ppvt = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes,
+            finfo, [fvars], [fdcs], ftypes,
             clean=customClean)[0]
         tpvt = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes,
+            finfo, [fvars], [fdcs], ftypes,
             typeClean=customTypeClean)[0]
         pp_tpvt = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes,
+            finfo, [fvars], [fdcs], ftypes,
             clean=customClean,
             typeClean=customTypeClean)[0]
         pp_tp_gpvt = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes,
+            finfo, [fvars], [fdcs], ftypes,
             clean=customClean,
             typeClean=customTypeClean,
             globalClean=customGlobalClean)[0]
@@ -282,10 +284,10 @@ def test_loadVariableTable_naValues():
     custom.registerBuiltIns()
 
     with tempdir() as td:
-        fdata, fvars, fdcs, ftypes = _prepare_variableTable(td)
+        finfo, fvars, fdcs, ftypes = _prepare_variableTable(td)
 
         vartable, _, _ = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes,
+            finfo, [fvars], [fdcs], ftypes,
             naValues={2   : [10, 20, 30],
                       99  : [10, 11, 12],
                       111 : [ 1,  2,  3]})
@@ -306,10 +308,10 @@ def test_loadVariableTable_recoding():
     custom.registerBuiltIns()
 
     with tempdir() as td:
-        fdata, fvars, fdcs, ftypes = _prepare_variableTable(td)
+        finfo, fvars, fdcs, ftypes = _prepare_variableTable(td)
 
         vartable, _, _ = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes,
+            finfo, [fvars], [fdcs], ftypes,
             recoding={2   : ([1, 2, 3],    [10, 20, 30]),
                       99  : ([40, 50],     [400, 500]),
                       111 : ([ 1,  2,  3], [100, 200, 300])})
@@ -334,7 +336,7 @@ def test_loadVariableTable_childValues():
     custom.registerBuiltIns()
 
     with tempdir() as td:
-        fdata, fvars, fdcs, ftypes = _prepare_variableTable(td)
+        finfo, fvars, fdcs, ftypes = _prepare_variableTable(td)
 
         childValues = {
             1   : ('v2 != 7', [12345]),
@@ -342,7 +344,7 @@ def test_loadVariableTable_childValues():
             111 : ('v1 == 6', [55555])}
 
         vartable, _, _ = loadtables.loadVariableTable(
-            [fdata], [fvars], [fdcs], ftypes,
+            finfo, [fvars], [fdcs], ftypes,
             childValues=childValues)
 
     expvids       = [1, 2, 5, 6, 99]
