@@ -21,6 +21,7 @@ from pandas.testing import assert_frame_equal
 
 import funpack.main       as main
 import funpack.custom     as custom
+import funpack.fileinfo   as fileinfo
 import funpack.importing  as importing
 import funpack.loadtables as loadtables
 import funpack.expression as expression
@@ -378,8 +379,9 @@ def test_main_visits():
 
         gen_test_data(10, 100, 'data.tsv', min_visits=2, max_visits=3)
 
-        tables = loadtables.loadTables(['data.tsv'])[:3]
-        dt, _  = importing.importData(['data.tsv'], *tables)
+        finfo  = fileinfo.FileInfo('data.tsv')
+        tables = loadtables.loadTables(finfo)[:3]
+        dt, _  = importing.importData(finfo, *tables)
 
         base = '-p plugin.py -ow -nb '
 
@@ -412,8 +414,9 @@ def test_main_subjects():
 
     with tempdir():
         gen_test_data(10, 20, 'data.tsv')
-        tables = loadtables.loadTables(['data.tsv'])[:3]
-        dt, _  = importing.importData(['data.tsv'], *tables)
+        finfo  = fileinfo.FileInfo('data.tsv')
+        tables = loadtables.loadTables(finfo)[:3]
+        dt, _  = importing.importData(finfo, *tables)
 
         args = ' -ow -sp out.tsv data.tsv'
 
@@ -476,8 +479,9 @@ def test_main_subject_expression():
 
         np.savetxt('data.tsv', data, delimiter='\t', header='\t'.join(cols))
 
-        tables = loadtables.loadTables(['data.tsv'])[:3]
-        dt, _  = importing.importData(['data.tsv'], *tables)
+        finfo  = fileinfo.FileInfo('data.tsv')
+        tables = loadtables.loadTables(finfo)[:3]
+        dt, _  = importing.importData(finfo, *tables)
 
         mask = np.zeros(30, dtype=np.bool)
 
@@ -504,8 +508,9 @@ def test_main_subjects_and_expression():
 
         np.savetxt('data.tsv', data, delimiter='\t', header='\t'.join(cols))
 
-        tables = loadtables.loadTables(['data.tsv'])[:3]
-        dt, _  = importing.importData(['data.tsv'], *tables)
+        finfo  = fileinfo.FileInfo('data.tsv')
+        tables = loadtables.loadTables(finfo)[:3]
+        dt, _  = importing.importData(finfo, *tables)
 
         with open('subjects.txt', 'wt') as f:
             f.write('\n'.join(map(str, [1, 2, 3])))
@@ -1552,3 +1557,45 @@ def test_ids_only():
         with open('out.txt') as f:
             got = f.read()
         assert got.strip() == exp
+
+
+@patch_logging
+def test_dupe_columns():
+    data       = np.random.randint(1, 100, (10, 3))
+    data[:, 0] = np.arange(1, 10 + 1)
+    colnames   = ['eid', '1-0.0', '1-0.0']
+
+    with tempdir():
+        with open('data.txt', 'wt') as f:
+            f.write('\t'.join(colnames) + '\n')
+            np.savetxt(f, data, fmt='%i', delimiter='\t')
+
+        main.main('-rd out.csv data.txt'.split())
+        df = pd.read_csv('out.csv')
+        assert list(df.columns) == ['eid', '1-0.0', '1-0.0.1']
+        assert np.all(df.to_numpy() == data)
+
+
+@patch_logging
+def test_dupe_columns_multiple_files():
+    data1       = np.random.randint(1, 100, (10, 3))
+    data1[:, 0] = np.arange(1, 10 + 1)
+    colnames1   = ['eid', '1-0.0', '2-0.0']
+    data2       = np.random.randint(1, 100, (10, 3))
+    data2[:, 0] = np.arange(1, 10 + 1)
+    colnames2   = ['eid', '2-0.0', '3-0.0']
+
+    with tempdir():
+        with open('data1.txt', 'wt') as f:
+            f.write('\t'.join(colnames1) + '\n')
+            np.savetxt(f, data1, fmt='%i', delimiter='\t')
+        with open('data2.txt', 'wt') as f:
+            f.write('\t'.join(colnames2) + '\n')
+            np.savetxt(f, data2, fmt='%i', delimiter='\t')
+
+        main.main('-rd out.csv data1.txt data2.txt'.split())
+        df = pd.read_csv('out.csv')
+        assert list(df.columns) == \
+            ['eid', '1-0.0', '2-0.0', '2-0.0.1', '3-0.0']
+        exp = np.hstack((data1, data2[:, 1:]))
+        assert np.all(df.to_numpy() == exp)
