@@ -373,6 +373,11 @@ def test_matrixRedundantColumns_associative():
     _test_redundantColumns_associative(core.matrixRedundantColumns)
 
 def _test_redundantColumns_associative(rcfunc):
+
+    seed = np.random.randint(2 ** 31)
+    np.random.seed(seed)
+    print('Seed for random number generator:', seed)
+
     a        = np.random.randint(1, 100, 100).astype(np.float32)
     b        = np.copy(a)
     c        = np.copy(a)
