@@ -20,6 +20,7 @@ import pandas as pd
 from pandas.testing import assert_frame_equal
 
 import funpack.importing            as importing
+import funpack.fileinfo             as fileinfo
 import funpack.util                 as util
 import funpack.processing_functions as pfns
 
@@ -215,7 +216,8 @@ def test_binariseCateorical():
     with tempdir():
         np.savetxt('data.txt', data, delimiter=',', header=','.join(cols))
         vartable, proctable, cattable = gen_tables(range(1, 13))[:3]
-        dt, _ = importing.importData('data.txt', vartable, proctable, cattable)
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         remove, add, addvids, kwargs = pfns.binariseCategorical(
             dt, vids,
@@ -331,7 +333,8 @@ def test_binariseCateorical_no_replace():
     with tempdir():
         np.savetxt('data.txt', data, delimiter=',', header=','.join(cols))
         vartable, proctable, cattable = gen_tables(vids)[:3]
-        dt, _ = importing.importData('data.txt', vartable, proctable, cattable)
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         remove, add, addvids, kwargs = pfns.binariseCategorical(
             dt, [1], replace=False, nameFormat='{vid}.{value}')
@@ -362,7 +365,8 @@ def test_binariseCategorical_nonnumeric():
                 f.write('{}, {}, {}\n'.format(i + 1, v1, v2))
 
         vartable, proctable, cattable = gen_tables([1])[:3]
-        dt, _ = importing.importData('data.txt', vartable, proctable, cattable)
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         remove, add, addvids, kwargs = pfns.binariseCategorical(
             dt, [1],
@@ -495,7 +499,8 @@ def test_binariseCategorical_take():
                 f.write(data)
 
             vartable, proctable, cattable = gen_tables([1, 2])[:3]
-            dt, _ = importing.importData('data.txt', vartable, proctable, cattable)
+            finfo = fileinfo.FileInfo('data.txt')
+            dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
             remove, add, addvids, kwargs = pfns.binariseCategorical(
                 dt, [1],
@@ -507,6 +512,48 @@ def test_binariseCategorical_take():
             assert_frame_equal(got, exp, check_dtype=False, check_like=False)
 
 
+
+def test_binariseCategorical_missing_vars():
+
+    data = np.random.randint(1, 10, (50, 5))
+    data[:, 0] = np.arange(1, 51)
+    cols = ['eid', '1-0.0', '2-0.0', '3-0.0', '4-0.0']
+    vids  = [1, 2, 3, 4]
+
+    nuniq = {i :  len(np.unique(data[:, i])) for i in [1, 2, 3, 4]}
+
+    with tempdir():
+        np.savetxt('data.txt', data, delimiter=',', header=','.join(cols))
+        vartable, proctable, cattable = gen_tables(vids)[:3]
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
+
+        series = pfns.binariseCategorical(dt, [1], take=[3])[1]
+        assert len(series) == nuniq[1]
+
+        series = pfns.binariseCategorical(dt, [1, 2], take=[3, 4])[1]
+        assert len(series) == nuniq[1] + nuniq[2]
+
+        series = pfns.binariseCategorical(dt, [1], take=[5])[1]
+        assert len(series) == 0
+
+        series = pfns.binariseCategorical(dt, [1, 2], take=[3, 5])[1]
+        assert len(series) == nuniq[1]
+
+        series = pfns.binariseCategorical(dt, [1, 5], take=[3, 6])[1]
+        assert len(series) == nuniq[1]
+
+        series = pfns.binariseCategorical(dt, [5])[1]
+        assert len(series) == 0
+
+        series = pfns.binariseCategorical(dt, [5], take=[6])[1]
+        assert len(series) == 0
+
+        series = pfns.binariseCategorical(dt, [5], take=[6])[1]
+        assert len(series) == 0
+
+
+
 @patch_logging
 def test_expandCompound():
 
@@ -530,7 +577,8 @@ def test_expandCompound():
                 f.write('\n')
 
         vartable, proctable, cattable = gen_tables([1])[:3]
-        dt, _ = importing.importData('data.txt', vartable, proctable, cattable)
+        finfo = fileinfo.FileInfo('data.txt')
+        dt, _ = importing.importData(finfo, vartable, proctable, cattable)
 
         dt[:, '1-0.0'] = dt[:, '1-0.0'].apply(
             lambda v: np.fromstring(v, sep=','))
